#!/bin/bash
set -euo pipefail
IFS=$'\n'

if [[ "$#" -eq 0 || "$#" -gt 1 ]]; then
  cat >&2 <<EOF
$(basename "$0") <JSON file>

Reformat a JSON file to use standard wrapping and indentation.
EOF
  exit 64
fi
JSON_FILE="$1"

# jq can't edit in place, so this slurps the entire output into memory before
# replacing the original file. Some care needs to be taken to ensure the
# reformat succeeded to avoid clobbering the input file.
FORMATTED="$(jq . < "${JSON_FILE}")"
if ! cmp "${JSON_FILE}" <<<"${FORMATTED}"; then
  echo "Reformatted: ${JSON_FILE}"
  cat <<<"${FORMATTED}" > "${JSON_FILE}"
fi
